GroupedConsumer

Struct GroupedConsumer 

pub struct GroupedConsumer { /* private fields */ }
Grouped consumer (worker) that receives assignments from a coordinator

Implementations

Source

impl GroupedConsumer

pub async fn join( server_addr: &str, coordinator_addr: SocketAddr, config: WorkerConfig, ) -> Result<Self, ClientError>

Join a consumer group by connecting to the coordinator

pub fn assignments(&self) -> &[u32]

Get current topic assignments

pub fn generation(&self) -> u64

Get current generation

pub async fn next_batch( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>

Receive the next batch for a specific assigned topic.

pub async fn consume( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>

Primary consume interface alias for a specific assigned topic.

pub async fn poll( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>

Compatibility wrapper for callers still using polling terminology.

pub async fn commit(&mut self, topic_id: u32) -> Result<(), ClientError>

Commit offset for a specific topic

pub async fn commit_all(&mut self) -> Result<(), ClientError>

Commit all topics

pub async fn heartbeat(&mut self) -> Result<u64, ClientError>

Send heartbeat to coordinator

pub async fn leave(self) -> Result<(), ClientError>

Leave the consumer group