pub struct GroupedConsumer { /* private fields */ }Expand description
Grouped consumer (worker) that receives assignments from a coordinator
Implementations
Sourceimpl GroupedConsumer
impl GroupedConsumer
Sourcepub async fn join(
server_addr: &str,
coordinator_addr: SocketAddr,
config: WorkerConfig,
) -> Result<Self, ClientError>
pub async fn join( server_addr: &str, coordinator_addr: SocketAddr, config: WorkerConfig, ) -> Result<Self, ClientError>
Join a consumer group by connecting to the coordinator
Sourcepub fn assignments(&self) -> &[u32]
pub fn assignments(&self) -> &[u32]
Get current topic assignments
Sourcepub fn generation(&self) -> u64
pub fn generation(&self) -> u64
Get current generation
Sourcepub async fn next_batch(
&mut self,
topic_id: u32,
) -> Result<Option<PollResult>, ClientError>
pub async fn next_batch( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>
Receive the next batch for a specific assigned topic.
Sourcepub async fn consume(
&mut self,
topic_id: u32,
) -> Result<Option<PollResult>, ClientError>
pub async fn consume( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>
Primary consume interface alias for a specific assigned topic.
Sourcepub async fn poll(
&mut self,
topic_id: u32,
) -> Result<Option<PollResult>, ClientError>
pub async fn poll( &mut self, topic_id: u32, ) -> Result<Option<PollResult>, ClientError>
Compatibility wrapper for callers still using polling terminology.
Sourcepub async fn commit(&mut self, topic_id: u32) -> Result<(), ClientError>
pub async fn commit(&mut self, topic_id: u32) -> Result<(), ClientError>
Commit offset for a specific topic
Sourcepub async fn commit_all(&mut self) -> Result<(), ClientError>
pub async fn commit_all(&mut self) -> Result<(), ClientError>
Commit all topics
Sourcepub async fn heartbeat(&mut self) -> Result<u64, ClientError>
pub async fn heartbeat(&mut self) -> Result<u64, ClientError>
Send heartbeat to coordinator
Sourcepub async fn leave(self) -> Result<(), ClientError>
pub async fn leave(self) -> Result<(), ClientError>
Leave the consumer group